<?php
namespace Bushelpowered\Api\Data\Analytics\V1\Response;
        
class InvoiceResponse 
{
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var null|string $sourceDisplayId Human-readable invoice identifier from the source system, if available.*/
    public ?string $sourceDisplayId = null;
    /** @var null|string $accountId The account identifier.*/
    public ?string $accountId = null;
    /** @var null|\Bushelpowered\Api\Data\Analytics\V1\Enums\InvoiceStatus $status */
    public ?\Bushelpowered\Api\Data\Analytics\V1\Enums\InvoiceStatus $status = null;
    /** @var string $sourceInvoiceDate Date when the invoice was issued in the source system. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceInvoiceDate;
    /** @var null|string $sourceInvoiceDueDate Due date for payment as specified in the source system, if available. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceInvoiceDueDate = null;
    /** @var null|string $sourceCurrency Currency code (e.g., USD, EUR) used in the invoice, if available.*/
    public ?string $sourceCurrency = null;
    /** @var float $sourceTotalAmount Total amount billed on the invoice, including taxes.*/
    public float $sourceTotalAmount;
    /** @var null|float $sourceTotalTax Total tax amount applied to the invoice, if available.*/
    public ?float $sourceTotalTax = null;
    /** @var \Bushelpowered\Api\Data\Analytics\V1\Response\InvoiceLineResponse[] $lineItems List of line items included in the invoice.*/
    public array $lineItems;

    /**
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $sourceId The source record identifier.
     * @param  null|string  $sourceDisplayId Human-readable invoice identifier from the source system, if available.
     * @param  null|string  $accountId The account identifier.
     * @param  null|\Bushelpowered\Api\Data\Analytics\V1\Enums\InvoiceStatus  $status 
     * @param  string  $sourceInvoiceDate Date when the invoice was issued in the source system. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceInvoiceDueDate Due date for payment as specified in the source system, if available. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceCurrency Currency code (e.g., USD, EUR) used in the invoice, if available.
     * @param  float  $sourceTotalAmount Total amount billed on the invoice, including taxes.
     * @param  null|float  $sourceTotalTax Total tax amount applied to the invoice, if available.
     * @param  \Bushelpowered\Api\Data\Analytics\V1\Response\InvoiceLineResponse[]  $lineItems List of line items included in the invoice.
     */
    public function __construct(string $tenantId, string $sourceId, ?string $sourceDisplayId, ?string $accountId, ?\Bushelpowered\Api\Data\Analytics\V1\Enums\InvoiceStatus $status, string $sourceInvoiceDate, ?string $sourceInvoiceDueDate, ?string $sourceCurrency, float $sourceTotalAmount, ?float $sourceTotalTax, array $lineItems)
    {
        $this->tenantId = $tenantId;
        $this->sourceId = $sourceId;
        $this->sourceDisplayId = $sourceDisplayId;
        $this->accountId = $accountId;
        $this->status = $status;
        $this->sourceInvoiceDate = $sourceInvoiceDate;
        $this->sourceInvoiceDueDate = $sourceInvoiceDueDate;
        $this->sourceCurrency = $sourceCurrency;
        $this->sourceTotalAmount = $sourceTotalAmount;
        $this->sourceTotalTax = $sourceTotalTax;
        $this->lineItems = $lineItems;
    }
    

}