<?php
namespace Bushelpowered\Api\Platform\Tenant\Event;
        
class AccountRawEvent implements \Bushelpowered\Api\Common\Event\Event, \Bushelpowered\Api\Common\Event\RawEvent
{
    /** @var \Bushelpowered\Api\Platform\Tenant\Event\AccountRawVersions $raw */
    public \Bushelpowered\Api\Platform\Tenant\Event\AccountRawVersions $raw;
    /** @var string $idempotencyKey A key to uniquely identify this event.*/
    public string $idempotencyKey;
    /** @var string $eventCreationTime The time the event was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $eventCreationTime;
    /** @var null|string $tenantId The tenant that this event belongs to/was emitted for. Null if an event is not for a specific tenant.*/
    public ?string $tenantId = null;
    /** @var null|string $deleteIntegrationId The integration id of an entity to delete.*/
    public ?string $deleteIntegrationId = null;

    /**
     * @param  \Bushelpowered\Api\Platform\Tenant\Event\AccountRawVersions  $raw 
     * @param  string  $idempotencyKey A key to uniquely identify this event.
     * @param  string  $eventCreationTime The time the event was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $tenantId The tenant that this event belongs to/was emitted for. Null if an event is not for a specific tenant.
     * @param  null|string  $deleteIntegrationId The integration id of an entity to delete.
     */
    public function __construct(\Bushelpowered\Api\Platform\Tenant\Event\AccountRawVersions $raw, string $idempotencyKey, string $eventCreationTime, ?string $tenantId, ?string $deleteIntegrationId)
    {
        $this->raw = $raw;
        $this->idempotencyKey = $idempotencyKey;
        $this->eventCreationTime = $eventCreationTime;
        $this->tenantId = $tenantId;
        $this->deleteIntegrationId = $deleteIntegrationId;
    }
    
    /**
     * @return \Bushelpowered\Api\Platform\Tenant\Event\AccountRawVersions 
     */
    public function getRaw(): \Bushelpowered\Api\Platform\Tenant\Event\AccountRawVersions
    {
        return $this->raw;
    }
    /**
     * @return string A key to uniquely identify this event.
     */
    public function getIdempotencyKey(): string
    {
        return $this->idempotencyKey;
    }
    /**
     * @return string The time the event was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getEventCreationTime(): string
    {
        return $this->eventCreationTime;
    }
    /**
     * @return null|string The tenant that this event belongs to/was emitted for. Null if an event is not for a specific tenant.
     */
    public function getTenantId(): ?string
    {
        return $this->tenantId;
    }
    /**
     * @return null|string The integration id of an entity to delete.
     */
    public function getDeleteIntegrationId(): ?string
    {
        return $this->deleteIntegrationId;
    }
}