<?php
namespace Bushelpowered\Api\Platform\Tenant\V1\Model;
        
class AccountStandard implements \Bushelpowered\Api\Common\Event\StandardRecord, \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $id The bushel id for this record.*/
    public string $id;
    /** @var string $tenantId The id of the tenant this record belongs to.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var null|string $sourceName The source account name.*/
    public ?string $sourceName = null;
    /** @var null|string $name */
    public ?string $name = null;
    /** @var null|string $accountId The bushel id of the account that owns this record, if any.*/
    public ?string $accountId = null;
    /** @var null|string $locationId The bushel id of the location that owns this record, if any.*/
    public ?string $locationId = null;
    /** @var string $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var string $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var null|string $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;

    /**
     * @param  string  $id The bushel id for this record.
     * @param  string  $tenantId The id of the tenant this record belongs to.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  null|string  $sourceName The source account name.
     * @param  null|string  $name 
     * @param  null|string  $accountId The bushel id of the account that owns this record, if any.
     * @param  null|string  $locationId The bushel id of the location that owns this record, if any.
     * @param  string  $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $tenantId, string $datasourceId, string $integrationId, string $sourceId, ?string $sourceName, ?string $name, ?string $accountId, ?string $locationId, string $updatedAt, string $createdAt, ?string $deletedAt)
    {
        $this->id = $id;
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceName = $sourceName;
        $this->name = $name;
        $this->accountId = $accountId;
        $this->locationId = $locationId;
        $this->updatedAt = $updatedAt;
        $this->createdAt = $createdAt;
        $this->deletedAt = $deletedAt;
    }
    
    /**
     * @return string The bushel id for this record.
     */
    public function getId(): string
    {
        return $this->id;
    }
    /**
     * @return string The id of the tenant this record belongs to.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The bushel id of the account that owns this record, if any.
     */
    public function getAccountId(): ?string
    {
        return $this->accountId;
    }
    /**
     * @return null|string The bushel id of the location that owns this record, if any.
     */
    public function getLocationId(): ?string
    {
        return $this->locationId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
}