<?php
namespace Bushelpowered\Api\Trade\Esign\V1\Request;
        
class CreateDocumentRequest implements \Bushelpowered\Api\Trade\Esign\V1\Request\EncodedPdf
{
    /** @var null|string $name The name of the Contract, shown to the grower user.*/
    public ?string $name = null;
    /** @var string $datasourceId The id of the datasource where this record came from.*/
    public string $datasourceId;
    /** @var string $signerBushelAccountId The bushel account id of the signer.*/
    public string $signerBushelAccountId;
    /** @var bool $isSigned Whether or not the document is signed by the creator.*/
    public bool $isSigned;
    /** @var string $file The PDF of the document base64 encoded.*/
    public string $file;
    /** @var null|string $version A version number for the contract. If id matches an existing contract, having a different version will create an amendment.*/
    public ?string $version = null;

    /**
     * @param  null|string  $name The name of the Contract, shown to the grower user.
     * @param  string  $datasourceId The id of the datasource where this record came from.
     * @param  string  $signerBushelAccountId The bushel account id of the signer.
     * @param  bool  $isSigned Whether or not the document is signed by the creator.
     * @param  string  $file The PDF of the document base64 encoded.
     * @param  null|string  $version A version number for the contract. If id matches an existing contract, having a different version will create an amendment.
     */
    public function __construct(?string $name, string $datasourceId, string $signerBushelAccountId, bool $isSigned, string $file, ?string $version)
    {
        $this->name = $name;
        $this->datasourceId = $datasourceId;
        $this->signerBushelAccountId = $signerBushelAccountId;
        $this->isSigned = $isSigned;
        $this->file = $file;
        $this->version = $version;
    }
    
    /**
     * @return string The PDF of the document base64 encoded.
     */
    public function getFile(): string
    {
        return $this->file;
    }
    /**
     * @return null|string A version number for the contract. If id matches an existing contract, having a different version will create an amendment.
     */
    public function getVersion(): ?string
    {
        return $this->version;
    }
}