<?php
namespace Bushelpowered\Api\Wallet\Permissions\Check;

use \Bushelpowered\Api\Wallet\Permissions\Check\Dto\PermissionsCheckRequest;
use \Bushelpowered\Api\Wallet\Permissions\Check\Dto\PermissionsCheckResponse;
use \Bushelpowered\Api\Common\NotAuthenticated;
use \Bushelpowered\Api\Common\NotAuthorized;
use \Bushelpowered\Api\Common\NotFound;
use \Bidl\Php\Core\Builtins\UnknownError;

class PermissionsCheck 
{
    public function __construct(public \Bidl\Php\Core\BidlClient $client)
    {
    }
    
    /**
     * @deprecated use request instead.
     */
    public function call(PermissionsCheckRequest $request, $headers): PermissionsCheckResponse | NotAuthenticated | NotAuthorized | NotFound | UnknownError
    {
         return $this->client->call('api/wallet/permissions/check/PermissionsCheck', $request, $this->getWrapper(), $headers);
    }
    
    public function request(PermissionsCheckRequest $request, PermissionsCheckMetadata $hasHeaders): PermissionsCheckResponse | NotAuthenticated | NotAuthorized | NotFound | UnknownError
    {
         return $this->client->call('api/wallet/permissions/check/PermissionsCheck', $request, $this->getWrapper(), $hasHeaders->getMetaData());
    }
    
    private function getWrapper() {
        return new class () implements \Bidl\Php\Core\BidlResponse {

            /** @var PermissionsCheckResponse | NotAuthenticated | NotAuthorized | NotFound | UnknownError */
            public $response;
        
            public function __construct()
            {
                $this->mapper = new \JsonMapper();
            }
            
            public function fromJson($data) 
            {
                switch($data->type) {
                  case 'api.wallet.permissions.check#PermissionsCheckSuccess':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Wallet\Permissions\Check\Dto\PermissionsCheckResponse::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthenticated':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthenticated::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthorized':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthorized::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotFound':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotFound::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                   default: 
                     $this->response = new \Bidl\Php\Core\Builtins\UnknownError('The response was not a valid bidl response.');
                }
            }
        };
    }
}